You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@stanbol.apache.org by rw...@apache.org on 2012/07/10 11:30:02 UTC

svn commit: r1359535 [1/4] - in /incubator/stanbol/trunk: contenthub/ldpath/ contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/ contenthub/search/related/ contenthub/search/related/src/main/java/org/apache/stanbol/contenthub/sea...

Author: rwesten
Date: Tue Jul 10 09:29:59 2012
New Revision: 1359535

URL: http://svn.apache.org/viewvc?rev=1359535&view=rev
Log:
Stanbol Entityhub ManagedSites (STANBOL-673)

* Lot of changes to modules because of the API changes described by STANBOL-674
* Implementation of the YardSite STANBOL-675 in the new entityhub.site.managed module
* Added ManagedSite specific features to the RESTful API

Notes: MaangedSites do use the new design pattern to split up the

1. OSGI component that retrieves the configuration and tracks dependencies
2. OSGI service that implements the interface and is registered/unregistered by the OSGI component

Added:
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/SiteManagerImpl.java   (contents, props changed)
      - copied, changed from r1356612, incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/ReferenceManagerImpl.java
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/site/ReferencedSiteConfigurationImpl.java   (with props)
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/site/SiteConfigurationImpl.java   (contents, props changed)
      - copied, changed from r1356612, incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/DefaultSiteConfiguration.java
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/utils/SiteUtils.java   (with props)
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ManagedSite.java   (with props)
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ManagedSiteConfiguration.java   (with props)
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ManagedSiteException.java   (with props)
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ReferencedSiteConfiguration.java   (with props)
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/Site.java   (contents, props changed)
      - copied, changed from r1356612, incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ReferencedSite.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/SiteException.java   (contents, props changed)
      - copied, changed from r1356612, incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ReferencedSiteException.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/SiteManager.java   (contents, props changed)
      - copied, changed from r1356612, incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ReferencedSiteManager.java
    incubator/stanbol/trunk/entityhub/site/managed/   (with props)
    incubator/stanbol/trunk/entityhub/site/managed/pom.xml   (with props)
    incubator/stanbol/trunk/entityhub/site/managed/src/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/stanbol/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/stanbol/entityhub/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/stanbol/entityhub/site/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/stanbol/entityhub/site/managed/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/stanbol/entityhub/site/managed/ManagedSiteComponent.java   (with props)
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/stanbol/entityhub/site/managed/ManagedSiteConfigurationImpl.java   (with props)
    incubator/stanbol/trunk/entityhub/site/managed/src/main/java/org/apache/stanbol/entityhub/site/managed/impl/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/resources/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/resources/OSGI-INF/
    incubator/stanbol/trunk/entityhub/site/managed/src/main/resources/OSGI-INF/metatype/
    incubator/stanbol/trunk/entityhub/site/managed/src/test/
    incubator/stanbol/trunk/entityhub/site/managed/src/test/java/
Removed:
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/DefaultSiteConfiguration.java
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/ReferenceManagerImpl.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ReferencedSite.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ReferencedSiteException.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/ReferencedSiteManager.java
Modified:
    incubator/stanbol/trunk/contenthub/ldpath/pom.xml
    incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java
    incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/SemanticIndexManagerImpl.java
    incubator/stanbol/trunk/contenthub/search/related/pom.xml
    incubator/stanbol/trunk/contenthub/search/related/src/main/java/org/apache/stanbol/contenthub/search/related/referencedsite/ReferencedSiteSearch.java
    incubator/stanbol/trunk/contenthub/web/pom.xml
    incubator/stanbol/trunk/contenthub/web/src/main/java/org/apache/stanbol/contenthub/web/resources/RelatedKeywordResource.java
    incubator/stanbol/trunk/enhancer/engines/entitytagging/pom.xml
    incubator/stanbol/trunk/enhancer/engines/entitytagging/src/main/java/org/apache/stanbol/enhancer/engines/entitytagging/impl/NamedEntityTaggingEngine.java
    incubator/stanbol/trunk/enhancer/engines/keywordextraction/pom.xml
    incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/engine/KeywordLinkingEngine.java
    incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/EntitySearcher.java
    incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/ReferencedSiteSearcher.java
    incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/TrackingEntitySearcher.java
    incubator/stanbol/trunk/enhancer/engines/refactor/pom.xml
    incubator/stanbol/trunk/enhancer/engines/refactor/src/main/java/org/apache/stanbol/enhancer/engines/refactor/RefactorEnhancementEngine.java
    incubator/stanbol/trunk/enhancer/engines/topic/pom.xml
    incubator/stanbol/trunk/enhancer/engines/topic/src/main/java/org/apache/stanbol/enhancer/engine/topic/TopicClassificationEngine.java
    incubator/stanbol/trunk/entityhub/bundlelist/pom.xml
    incubator/stanbol/trunk/entityhub/bundlelist/src/main/bundles/list.xml
    incubator/stanbol/trunk/entityhub/defaults/pom.xml
    incubator/stanbol/trunk/entityhub/generic/core/pom.xml
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/EntityhubImpl.java
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/ReferencedSiteImpl.java
    incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/site/AbstractEntitySearcher.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/pom.xml
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/Entityhub.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/EntityhubConfiguration.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/mapping/FieldMapperConfig.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/query/Query.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/EntityDereferencer.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/EntitySearcher.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/site/SiteConfiguration.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/yard/Cache.java
    incubator/stanbol/trunk/entityhub/generic/servicesapi/src/main/java/org/apache/stanbol/entityhub/servicesapi/yard/Yard.java
    incubator/stanbol/trunk/entityhub/generic/test/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/core/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/dblp/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/dbpedia/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/destination/solryard/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/genericrdf/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/geonames/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/parent/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/source/jenatdb/pom.xml
    incubator/stanbol/trunk/entityhub/indexing/source/vcard/pom.xml
    incubator/stanbol/trunk/entityhub/jersey/pom.xml
    incubator/stanbol/trunk/entityhub/jersey/src/main/java/org/apache/stanbol/entityhub/jersey/parsers/RepresentationReader.java
    incubator/stanbol/trunk/entityhub/jersey/src/main/java/org/apache/stanbol/entityhub/jersey/resource/EntityhubRootResource.java
    incubator/stanbol/trunk/entityhub/jersey/src/main/java/org/apache/stanbol/entityhub/jersey/resource/ReferencedSiteRootResource.java
    incubator/stanbol/trunk/entityhub/jersey/src/main/java/org/apache/stanbol/entityhub/jersey/resource/SiteManagerRootResource.java
    incubator/stanbol/trunk/entityhub/jersey/src/main/java/org/apache/stanbol/entityhub/jersey/resource/reconcile/BaseGoogleRefineReconcileResource.java
    incubator/stanbol/trunk/entityhub/jersey/src/main/java/org/apache/stanbol/entityhub/jersey/resource/reconcile/ReferencedSiteReconcileResource.java
    incubator/stanbol/trunk/entityhub/jersey/src/main/java/org/apache/stanbol/entityhub/jersey/resource/reconcile/SiteManagerReconcileResource.java
    incubator/stanbol/trunk/entityhub/jersey/src/main/resources/org/apache/stanbol/entityhub/jersey/templates/org/apache/stanbol/entityhub/jersey/resource/ReferencedSiteRootResource/inc_entity.ftl
    incubator/stanbol/trunk/entityhub/ldpath/pom.xml
    incubator/stanbol/trunk/entityhub/ldpath/src/main/java/org/apache/stanbol/entityhub/ldpath/backend/SiteBackend.java
    incubator/stanbol/trunk/entityhub/ldpath/src/main/java/org/apache/stanbol/entityhub/ldpath/backend/SiteManagerBackend.java
    incubator/stanbol/trunk/entityhub/model/clerezza/pom.xml
    incubator/stanbol/trunk/entityhub/parent/pom.xml
    incubator/stanbol/trunk/entityhub/pom.xml
    incubator/stanbol/trunk/entityhub/query/clerezza/pom.xml
    incubator/stanbol/trunk/entityhub/site/linkeddata/pom.xml
    incubator/stanbol/trunk/entityhub/yard/clerezza/pom.xml
    incubator/stanbol/trunk/entityhub/yard/solr/pom.xml
    incubator/stanbol/trunk/integration-tests/pom.xml
    incubator/stanbol/trunk/launchers/full-war/pom.xml
    incubator/stanbol/trunk/launchers/full/pom.xml
    incubator/stanbol/trunk/launchers/stable/pom.xml

Modified: incubator/stanbol/trunk/contenthub/ldpath/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/ldpath/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/ldpath/pom.xml (original)
+++ incubator/stanbol/trunk/contenthub/ldpath/pom.xml Tue Jul 10 09:29:59 2012
@@ -75,8 +75,13 @@
     </dependency>
     <dependency>
       <groupId>org.apache.stanbol</groupId>
+      <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
+      <version>0.11.0-incubating-SNAPSHOT</version>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.ldpath</artifactId>
-      <version>0.9.0-incubating</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </dependency>
       
     <dependency>

Modified: incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java (original)
+++ incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/LDPathUtils.java Tue Jul 10 09:29:59 2012
@@ -45,7 +45,7 @@ import org.apache.commons.io.IOUtils;
 import org.apache.stanbol.contenthub.servicesapi.Constants;
 import org.apache.stanbol.contenthub.servicesapi.ldpath.LDPathException;
 import org.apache.stanbol.entityhub.ldpath.backend.SiteManagerBackend;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
 import org.osgi.framework.Bundle;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -130,7 +130,7 @@ public class LDPathUtils {
 
     private Bundle bundle;
 
-    private ReferencedSiteManager referencedSiteManager;
+    private SiteManager referencedSiteManager;
 
     /**
      * Constructor taking a {@link Bundle} parameter. This bundle is used when obtaining Solr schema template.
@@ -138,7 +138,7 @@ public class LDPathUtils {
      * @param bundle
      *            From which the template Solr schema is obtained.
      */
-    public LDPathUtils(Bundle bundle, ReferencedSiteManager referencedSiteManager) {
+    public LDPathUtils(Bundle bundle, SiteManager referencedSiteManager) {
         this.bundle = bundle;
         this.referencedSiteManager = referencedSiteManager;
     }

Modified: incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/SemanticIndexManagerImpl.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/SemanticIndexManagerImpl.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/SemanticIndexManagerImpl.java (original)
+++ incubator/stanbol/trunk/contenthub/ldpath/src/main/java/org/apache/stanbol/contenthub/ldpath/solr/SemanticIndexManagerImpl.java Tue Jul 10 09:29:59 2012
@@ -44,7 +44,7 @@ import org.apache.stanbol.entityhub.ldpa
 import org.apache.stanbol.entityhub.ldpath.backend.SiteManagerBackend;
 import org.apache.stanbol.entityhub.servicesapi.model.Representation;
 import org.apache.stanbol.entityhub.servicesapi.model.ValueFactory;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
 import org.osgi.framework.Bundle;
 import org.osgi.service.component.ComponentContext;
 import org.slf4j.Logger;
@@ -83,7 +83,7 @@ public class SemanticIndexManagerImpl im
     private ManagedSolrServer managedSolrServer;
 
     @Reference
-    private ReferencedSiteManager referencedSiteManager;
+    private SiteManager referencedSiteManager;
 
     @Activate
     public void activator(ComponentContext cc) throws LDPathException, IOException {

Modified: incubator/stanbol/trunk/contenthub/search/related/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/search/related/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/search/related/pom.xml (original)
+++ incubator/stanbol/trunk/contenthub/search/related/pom.xml Tue Jul 10 09:29:59 2012
@@ -46,6 +46,11 @@
   <dependencies>
     <dependency>
       <groupId>org.apache.stanbol</groupId>
+      <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
+      <version>0.11.0-incubating-SNAPSHOT</version>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.model.clerezza</artifactId>
       <version>0.9.0-incubating</version>
     </dependency>

Modified: incubator/stanbol/trunk/contenthub/search/related/src/main/java/org/apache/stanbol/contenthub/search/related/referencedsite/ReferencedSiteSearch.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/search/related/src/main/java/org/apache/stanbol/contenthub/search/related/referencedsite/ReferencedSiteSearch.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/search/related/src/main/java/org/apache/stanbol/contenthub/search/related/referencedsite/ReferencedSiteSearch.java (original)
+++ incubator/stanbol/trunk/contenthub/search/related/src/main/java/org/apache/stanbol/contenthub/search/related/referencedsite/ReferencedSiteSearch.java Tue Jul 10 09:29:59 2012
@@ -45,7 +45,7 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.query.QueryResultList;
 import org.apache.stanbol.entityhub.servicesapi.query.TextConstraint;
 import org.apache.stanbol.entityhub.servicesapi.query.TextConstraint.PatternType;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -96,7 +96,7 @@ public class ReferencedSiteSearch implem
     private Entityhub entityhub;
 
     @Reference
-    private ReferencedSiteManager referencedSiteManager;
+    private SiteManager referencedSiteManager;
 
     @Override
     public Map<String,List<RelatedKeyword>> search(String keyword) throws SearchException {

Modified: incubator/stanbol/trunk/contenthub/web/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/web/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/web/pom.xml (original)
+++ incubator/stanbol/trunk/contenthub/web/pom.xml Tue Jul 10 09:29:59 2012
@@ -125,8 +125,13 @@
       a solution not to get this dependency -->
     <dependency>
       <groupId>org.apache.stanbol</groupId>
+      <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
+      <version>0.11.0-incubating-SNAPSHOT</version>
+    </dependency>
+    <dependency>
+      <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.core</artifactId>
-      <version>0.9.0-incubating</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </dependency>
 
     <!-- needed for the ContentItem resource -->

Modified: incubator/stanbol/trunk/contenthub/web/src/main/java/org/apache/stanbol/contenthub/web/resources/RelatedKeywordResource.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/contenthub/web/src/main/java/org/apache/stanbol/contenthub/web/resources/RelatedKeywordResource.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/contenthub/web/src/main/java/org/apache/stanbol/contenthub/web/resources/RelatedKeywordResource.java (original)
+++ incubator/stanbol/trunk/contenthub/web/src/main/java/org/apache/stanbol/contenthub/web/resources/RelatedKeywordResource.java Tue Jul 10 09:29:59 2012
@@ -52,7 +52,7 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.query.QueryResultList;
 import org.apache.stanbol.entityhub.servicesapi.query.TextConstraint;
 import org.apache.stanbol.entityhub.servicesapi.query.TextConstraint.PatternType;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
 import org.codehaus.jettison.json.JSONObject;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
@@ -73,12 +73,12 @@ public class RelatedKeywordResource exte
 
     private static String DEFAULT_AUTOCOMPLETE_SEARCH_FIELD = RDFS.label.getUnicodeString();
 
-    private ReferencedSiteManager referencedSiteManager;
+    private SiteManager referencedSiteManager;
 
     private RelatedKeywordSearchManager relatedKeywordSearchManager;
 
     public RelatedKeywordResource(@Context ServletContext context) {
-        referencedSiteManager = ContextHelper.getServiceFromContext(ReferencedSiteManager.class, context);
+        referencedSiteManager = ContextHelper.getServiceFromContext(SiteManager.class, context);
         relatedKeywordSearchManager = ContextHelper.getServiceFromContext(RelatedKeywordSearchManager.class,
             context);
     }

Modified: incubator/stanbol/trunk/enhancer/engines/entitytagging/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/entitytagging/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/entitytagging/pom.xml (original)
+++ incubator/stanbol/trunk/enhancer/engines/entitytagging/pom.xml Tue Jul 10 09:29:59 2012
@@ -93,7 +93,7 @@
     <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
       <scope>compile</scope>
     </dependency>
     <dependency>
@@ -141,13 +141,13 @@
      <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.core</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
       <scope>test</scope>
     </dependency>
      <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.yard.solr</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
       <scope>test</scope>
     </dependency>
      <dependency>

Modified: incubator/stanbol/trunk/enhancer/engines/entitytagging/src/main/java/org/apache/stanbol/enhancer/engines/entitytagging/impl/NamedEntityTaggingEngine.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/entitytagging/src/main/java/org/apache/stanbol/enhancer/engines/entitytagging/impl/NamedEntityTaggingEngine.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/keywordextraction/pom.xml (original)
+++ incubator/stanbol/trunk/enhancer/engines/keywordextraction/pom.xml Tue Jul 10 09:29:59 2012
@@ -92,7 +92,7 @@
     <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
-      <version>0.9.0-incubating</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
       <scope>compile</scope>
     </dependency>
     <dependency>
@@ -146,7 +146,7 @@
     <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.core</artifactId>
-      <version>0.9.0-incubating</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
       <scope>test</scope>
     </dependency>
     <dependency>

Modified: incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/engine/KeywordLinkingEngine.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/engine/KeywordLinkingEngine.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/engine/KeywordLinkingEngine.java (original)
+++ incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/engine/KeywordLinkingEngine.java Tue Jul 10 09:29:59 2012
@@ -83,7 +83,6 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.model.Reference;
 import org.apache.stanbol.entityhub.servicesapi.model.Text;
 import org.apache.stanbol.entityhub.servicesapi.model.rdf.RdfResourceEnum;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSite;
 import org.osgi.framework.Constants;
 import org.osgi.service.cm.ConfigurationException;
 import org.osgi.service.component.ComponentContext;

Modified: incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/EntitySearcher.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/EntitySearcher.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/EntitySearcher.java (original)
+++ incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/EntitySearcher.java Tue Jul 10 09:29:59 2012
@@ -24,7 +24,6 @@ import java.util.Set;
 import org.apache.stanbol.entityhub.servicesapi.Entityhub;
 import org.apache.stanbol.entityhub.servicesapi.model.Representation;
 import org.apache.stanbol.entityhub.servicesapi.query.TextConstraint;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSite;
 
 /**
  * Interface used to search for Entities (e.g. as defined by a Controlled

Modified: incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/ReferencedSiteSearcher.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/ReferencedSiteSearcher.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/ReferencedSiteSearcher.java (original)
+++ incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/ReferencedSiteSearcher.java Tue Jul 10 09:29:59 2012
@@ -28,19 +28,19 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.model.Representation;
 import org.apache.stanbol.entityhub.servicesapi.query.FieldQuery;
 import org.apache.stanbol.entityhub.servicesapi.query.QueryResultList;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSite;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteException;
+import org.apache.stanbol.entityhub.servicesapi.site.Site;
 import org.apache.stanbol.entityhub.servicesapi.site.SiteConfiguration;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteException;
 import org.osgi.framework.BundleContext;
 
-public final class ReferencedSiteSearcher extends TrackingEntitySearcher<ReferencedSite> implements EntitySearcher {
+public final class ReferencedSiteSearcher extends TrackingEntitySearcher<Site> implements EntitySearcher {
     
     
     private final String siteId;
     private final Integer limit;
 
     public ReferencedSiteSearcher(BundleContext context,String siteId, Integer limit) {
-        super(context, ReferencedSite.class, 
+        super(context, Site.class, 
             Collections.singletonMap(SiteConfiguration.ID,siteId));
         this.siteId = siteId;
         this.limit = limit != null && limit > 0 ? limit : null;
@@ -52,13 +52,13 @@ public final class ReferencedSiteSearche
             return null;
         }
         Entity entity;
-        ReferencedSite site = getSearchService();
+        Site site = getSearchService();
         if(site == null){
             throw new IllegalStateException("ReferencedSite "+siteId+" is currently not available");
         }
         try {
             entity = site.getEntity(id);
-        }  catch (ReferencedSiteException e) {
+        }  catch (SiteException e) {
             throw new IllegalStateException("Exception while getting "+id+
                 " from the ReferencedSite "+site.getId(),e);
         }
@@ -71,7 +71,7 @@ public final class ReferencedSiteSearche
                                            List<String> search,
                                            String... languages) throws IllegalStateException {
         //build the query and than return the result
-        ReferencedSite site = getSearchService();
+        Site site = getSearchService();
         if(site == null){
             throw new IllegalStateException("ReferencedSite "+siteId+" is currently not available");
         }
@@ -83,7 +83,7 @@ public final class ReferencedSiteSearche
         QueryResultList<Representation> results;
         try {
             results = site.find(query);
-        } catch (ReferencedSiteException e) {
+        } catch (SiteException e) {
             throw new IllegalStateException("Exception while searchign for "+
                 search+'@'+Arrays.toString(languages)+"in the ReferencedSite "+
                 site.getId(), e);
@@ -93,7 +93,7 @@ public final class ReferencedSiteSearche
 
     @Override
     public boolean supportsOfflineMode() {
-        ReferencedSite site = getSearchService();
+        Site site = getSearchService();
         //Do not throw an exception here if the site is not available. Just return false
         return site == null ? false : site.supportsLocalMode();
     }

Modified: incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/TrackingEntitySearcher.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/TrackingEntitySearcher.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/TrackingEntitySearcher.java (original)
+++ incubator/stanbol/trunk/enhancer/engines/keywordextraction/src/main/java/org/apache/stanbol/enhancer/engines/keywordextraction/linking/impl/TrackingEntitySearcher.java Tue Jul 10 09:29:59 2012
@@ -20,7 +20,6 @@ import java.util.Map;
 import java.util.Map.Entry;
 
 import org.apache.stanbol.enhancer.engines.keywordextraction.linking.EntitySearcher;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSite;
 import org.apache.stanbol.entityhub.servicesapi.site.SiteConfiguration;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.Filter;

Modified: incubator/stanbol/trunk/enhancer/engines/refactor/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/refactor/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/refactor/pom.xml (original)
+++ incubator/stanbol/trunk/enhancer/engines/refactor/pom.xml Tue Jul 10 09:29:59 2012
@@ -87,7 +87,7 @@
     <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
-      <version>0.9.0-incubating</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </dependency>
     <dependency>
       <groupId>org.apache.stanbol</groupId>

Modified: incubator/stanbol/trunk/enhancer/engines/refactor/src/main/java/org/apache/stanbol/enhancer/engines/refactor/RefactorEnhancementEngine.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/refactor/src/main/java/org/apache/stanbol/enhancer/engines/refactor/RefactorEnhancementEngine.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/refactor/src/main/java/org/apache/stanbol/enhancer/engines/refactor/RefactorEnhancementEngine.java (original)
+++ incubator/stanbol/trunk/enhancer/engines/refactor/src/main/java/org/apache/stanbol/enhancer/engines/refactor/RefactorEnhancementEngine.java Tue Jul 10 09:29:59 2012
@@ -57,7 +57,7 @@ import org.apache.stanbol.entityhub.core
 import org.apache.stanbol.entityhub.model.clerezza.RdfRepresentation;
 import org.apache.stanbol.entityhub.model.clerezza.RdfValueFactory;
 import org.apache.stanbol.entityhub.servicesapi.model.Entity;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
 import org.apache.stanbol.ontologymanager.ontonet.api.ONManager;
 import org.apache.stanbol.ontologymanager.ontonet.api.collector.DuplicateIDException;
 import org.apache.stanbol.ontologymanager.ontonet.api.collector.UnmodifiableOntologyCollectorException;
@@ -169,7 +169,7 @@ public class RefactorEnhancementEngine e
     Refactorer refactorer;
 
     @Reference
-    ReferencedSiteManager referencedSiteManager;
+    SiteManager referencedSiteManager;
 
     @Reference
     RuleStore ruleStore;

Modified: incubator/stanbol/trunk/enhancer/engines/topic/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/topic/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/topic/pom.xml (original)
+++ incubator/stanbol/trunk/enhancer/engines/topic/pom.xml Tue Jul 10 09:29:59 2012
@@ -273,7 +273,7 @@
     <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
-      <version>0.9.0-incubating</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </dependency>
     <dependency>
       <groupId>org.apache.stanbol</groupId>

Modified: incubator/stanbol/trunk/enhancer/engines/topic/src/main/java/org/apache/stanbol/enhancer/engine/topic/TopicClassificationEngine.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/topic/src/main/java/org/apache/stanbol/enhancer/engine/topic/TopicClassificationEngine.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/enhancer/engines/topic/src/main/java/org/apache/stanbol/enhancer/engine/topic/TopicClassificationEngine.java (original)
+++ incubator/stanbol/trunk/enhancer/engines/topic/src/main/java/org/apache/stanbol/enhancer/engine/topic/TopicClassificationEngine.java Tue Jul 10 09:29:59 2012
@@ -101,7 +101,7 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.model.Entity;
 import org.apache.stanbol.entityhub.servicesapi.model.Representation;
 import org.apache.stanbol.entityhub.servicesapi.model.Text;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.Constants;
 import org.osgi.framework.InvalidSyntaxException;
@@ -226,7 +226,7 @@ public class TopicClassificationEngine e
     protected Entityhub entityhub;
 
     @Reference
-    protected ReferencedSiteManager referencedSiteManager;
+    protected SiteManager referencedSiteManager;
 
     // TODO: make the following fields configurable
 

Modified: incubator/stanbol/trunk/entityhub/bundlelist/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/entityhub/bundlelist/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/entityhub/bundlelist/pom.xml (original)
+++ incubator/stanbol/trunk/entityhub/bundlelist/pom.xml Tue Jul 10 09:29:59 2012
@@ -16,13 +16,13 @@
   <parent>
     <groupId>org.apache.stanbol</groupId>
     <artifactId>org.apache.stanbol.entityhub.parent</artifactId>
-    <version>0.10.1-incubating-SNAPSHOT</version>
+    <version>0.11.0-incubating-SNAPSHOT</version>
     <relativePath>../parent</relativePath>
   </parent>
 
   <groupId>org.apache.stanbol</groupId>
   <artifactId>org.apache.stanbol.entityhub.bundlelist</artifactId>
-  <version>0.10.1-incubating-SNAPSHOT</version>
+  <version>0.11.0-incubating-SNAPSHOT</version>
   <packaging>partialbundlelist</packaging>
   
   <name>Apache Stanbol Entityhub Bundle List</name>

Modified: incubator/stanbol/trunk/entityhub/bundlelist/src/main/bundles/list.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/entityhub/bundlelist/src/main/bundles/list.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/entityhub/bundlelist/src/main/bundles/list.xml (original)
+++ incubator/stanbol/trunk/entityhub/bundlelist/src/main/bundles/list.xml Tue Jul 10 09:29:59 2012
@@ -22,42 +22,47 @@
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.model.clerezza</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.query.clerezza</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
+    </bundle>
+    <bundle>
+      <groupId>org.apache.stanbol</groupId>
+      <artifactId>org.apache.stanbol.entityhub.site.managed</artifactId>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.site.linkeddata</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.yard.clerezza</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.yard.solr</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.core</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.ldpath</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>   
 <!--     <bundle> 
       <groupId>org.jdom</groupId>
@@ -72,7 +77,7 @@
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.jersey</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
   </startLevel>  
   <!-- Default configuration for the Entityhub -->
@@ -80,7 +85,7 @@
     <bundle>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.defaults</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </bundle>
   </startLevel>  
 </bundles>  
\ No newline at end of file

Modified: incubator/stanbol/trunk/entityhub/defaults/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/entityhub/defaults/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/entityhub/defaults/pom.xml (original)
+++ incubator/stanbol/trunk/entityhub/defaults/pom.xml Tue Jul 10 09:29:59 2012
@@ -16,13 +16,13 @@
   <parent>
     <groupId>org.apache.stanbol</groupId>
     <artifactId>org.apache.stanbol.entityhub.parent</artifactId>
-    <version>0.10.1-incubating-SNAPSHOT</version>
+    <version>0.11.0-incubating-SNAPSHOT</version>
     <relativePath>../parent/pom.xml</relativePath>
   </parent>
 
   <groupId>org.apache.stanbol</groupId>
   <artifactId>org.apache.stanbol.entityhub.defaults</artifactId>
-  <version>0.10.1-incubating-SNAPSHOT</version>
+  <version>0.11.0-incubating-SNAPSHOT</version>
   <packaging>bundle</packaging>
 
   <name>Apache Stanbol Entityhub Default Configuration</name>

Modified: incubator/stanbol/trunk/entityhub/generic/core/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/entityhub/generic/core/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/entityhub/generic/core/pom.xml (original)
+++ incubator/stanbol/trunk/entityhub/generic/core/pom.xml Tue Jul 10 09:29:59 2012
@@ -22,13 +22,13 @@
   <parent>
     <groupId>org.apache.stanbol</groupId>
     <artifactId>org.apache.stanbol.entityhub.parent</artifactId>
-    <version>0.10.1-incubating-SNAPSHOT</version>
+    <version>0.11.0-incubating-SNAPSHOT</version>
     <relativePath>../../parent</relativePath>
   </parent>
 
   <groupId>org.apache.stanbol</groupId>
   <artifactId>org.apache.stanbol.entityhub.core</artifactId>
-  <version>0.10.1-incubating-SNAPSHOT</version>
+  <version>0.11.0-incubating-SNAPSHOT</version>
   <packaging>bundle</packaging>
 
   <name>Apache Stanbol Entityhub Generic Core</name>
@@ -92,7 +92,7 @@
     <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.servicesapi</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
     </dependency>
     <dependency>
       <groupId>org.apache.stanbol</groupId>
@@ -134,7 +134,7 @@
     <dependency>
       <groupId>org.apache.stanbol</groupId>
       <artifactId>org.apache.stanbol.entityhub.test</artifactId>
-      <version>0.10.1-incubating-SNAPSHOT</version>
+      <version>0.11.0-incubating-SNAPSHOT</version>
       <scope>test</scope>
     </dependency>
     <dependency>

Modified: incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/EntityhubImpl.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/EntityhubImpl.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/EntityhubImpl.java (original)
+++ incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/EntityhubImpl.java Tue Jul 10 09:29:59 2012
@@ -54,8 +54,11 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.query.FieldQueryFactory;
 import org.apache.stanbol.entityhub.servicesapi.query.QueryResultList;
 import org.apache.stanbol.entityhub.servicesapi.query.ReferenceConstraint;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSite;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.ManagedSiteConfiguration;
+import org.apache.stanbol.entityhub.servicesapi.site.Site;
+import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteConfiguration;
 import org.apache.stanbol.entityhub.servicesapi.util.ModelUtils;
 import org.apache.stanbol.entityhub.servicesapi.yard.Yard;
 import org.apache.stanbol.entityhub.servicesapi.yard.YardException;
@@ -102,7 +105,7 @@ public final class EntityhubImpl impleme
      * The site manager is used to search for entities within the Entityhub framework
      */
     @Reference // 1..1, static
-    private ReferencedSiteManager siteManager;
+    private SiteManager siteManager;
 
     private static final String DEFAULT_MANAGED_ENTITY_PREFIX = "entity";
     private static final String DEFAULT_MAPPING_PREFIX = "mapping";
@@ -442,7 +445,7 @@ public final class EntityhubImpl impleme
         if(remoteEntity == null){
             return null;
         }
-        ReferencedSite site = siteManager.getReferencedSite(remoteEntity.getSite());
+        Site site = siteManager.getSite(remoteEntity.getSite());
         if(site == null){
             log.warn("Unable to import Entity {} because the ReferencedSite {} is currently not active -> return null",
                 remoteEntity.getId(),remoteEntity.getSite());
@@ -467,7 +470,7 @@ public final class EntityhubImpl impleme
         return localEntity;
     }
     /**
-     * Imports a {@link Entity} from a {@link ReferencedSite}. This Method imports
+     * Imports a {@link Entity} from a {@link Site}. This Method imports
      * the {@link Representation} by applying all configured mappings. It also
      * sets the {@link ManagedEntityState} to the configured default value by the 
      * referenced site of the imported entity or the default for the Entityhub 
@@ -478,11 +481,13 @@ public final class EntityhubImpl impleme
      * @param valueFactory the valusFactory used to create instance while importing
      */
     private void importEntity(Entity remoteEntity,
-                              ReferencedSite site,
+                              Site site,
                               Entity localEntity,
                               ValueFactory valueFactory) {
         
-        ManagedEntityState state = site.getConfiguration().getDefaultManagedEntityState();
+        SiteConfiguration siteConfig = site.getConfiguration();
+        ManagedEntityState state;
+        state = siteConfig.getDefaultManagedEntityState();
         if(state == null){
             state =  config.getDefaultManagedEntityState();
         }
@@ -518,18 +523,19 @@ public final class EntityhubImpl impleme
      */
     private EntityMapping establishMapping(Entity localEntity,
                                            Entity remoteEntity,
-                                           ReferencedSite site,
+                                           Site site,
                                            Entity entityMappingEntity) {
         EntityMapping entityMapping = EntityMapping.init(entityMappingEntity);
         //now init the mappingState and the expireDate based on the config of the
         //ReferencedSite of the source entity (considering also the defaults of the entityhub)
-        MappingState mappingState = site.getConfiguration().getDefaultMappedEntityState();
+        SiteConfiguration siteConfig = site.getConfiguration();
+        MappingState mappingState = siteConfig.getDefaultMappedEntityState();
         if(mappingState == null){
             mappingState = config.getDefaultMappingState();
         }
         entityMapping.setState(mappingState);
-        long expireDuration = site.getConfiguration().getDefaultExpireDuration();
-        if(expireDuration < 0){
+        long expireDuration = siteConfig.getDefaultExpireDuration();
+        if(expireDuration > 0){
             Date expireDate = new Date(System.currentTimeMillis()+expireDuration);
             entityMapping.setExpires(expireDate);
         }

Modified: incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/ReferencedSiteImpl.java
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/ReferencedSiteImpl.java?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================
--- incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/ReferencedSiteImpl.java (original)
+++ incubator/stanbol/trunk/entityhub/generic/core/src/main/java/org/apache/stanbol/entityhub/core/impl/ReferencedSiteImpl.java Tue Jul 10 09:29:59 2012
@@ -16,9 +16,25 @@
  */
 package org.apache.stanbol.entityhub.core.impl;
 
+import static java.util.Collections.singletonMap;
+import static org.apache.stanbol.entityhub.core.utils.SiteUtils.extractSiteMetadata;
+import static org.apache.stanbol.entityhub.core.utils.SiteUtils.initEntityMetadata;
+import static org.apache.stanbol.entityhub.servicesapi.site.Site.PROHIBITED_SITE_IDS;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.ACCESS_URI;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.CACHE_ID;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.CACHE_STRATEGY;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.DEFAULT_EXPIRE_DURATION;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.DEFAULT_MAPPING_STATE;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.DEFAULT_SYMBOL_STATE;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.ENTITY_DEREFERENCER_TYPE;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.ENTITY_SEARCHER_TYPE;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.QUERY_URI;
+import static org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration.SITE_FIELD_MAPPINGS;
+
 import java.io.IOException;
 import java.io.InputStream;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.Dictionary;
 import java.util.Enumeration;
 import java.util.HashMap;
@@ -46,7 +62,9 @@ import org.apache.stanbol.entityhub.core
 import org.apache.stanbol.entityhub.core.model.InMemoryValueFactory;
 import org.apache.stanbol.entityhub.core.query.DefaultQueryFactory;
 import org.apache.stanbol.entityhub.core.query.QueryResultListImpl;
+import org.apache.stanbol.entityhub.core.site.ReferencedSiteConfigurationImpl;
 import org.apache.stanbol.entityhub.core.utils.OsgiUtils;
+import org.apache.stanbol.entityhub.core.utils.SiteUtils;
 import org.apache.stanbol.entityhub.servicesapi.defaults.NamespaceEnum;
 import org.apache.stanbol.entityhub.servicesapi.mapping.FieldMapper;
 import org.apache.stanbol.entityhub.servicesapi.mapping.FieldMapping;
@@ -60,8 +78,9 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.site.EntityDereferencer;
 import org.apache.stanbol.entityhub.servicesapi.site.EntitySearcher;
 import org.apache.stanbol.entityhub.servicesapi.site.License;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSite;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteException;
+import org.apache.stanbol.entityhub.servicesapi.site.Site;
+import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteConfiguration;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteException;
 import org.apache.stanbol.entityhub.servicesapi.site.SiteConfiguration;
 import org.apache.stanbol.entityhub.servicesapi.yard.Cache;
 import org.apache.stanbol.entityhub.servicesapi.yard.CacheStrategy;
@@ -83,11 +102,11 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * This in the Default implementation of the {@link ReferencedSite} interface.
+ * This in the Default implementation of the {@link Site} interface.
  * However this implementation forwards calls to methods defined within the
  * {@link EntityDereferencer} and {@link EntitySearcher} to sub components
  * (See the detailed description below).<p>
- * Each {@link ReferencedSite} with an {@link CacheStrategy} other than
+ * Each {@link Site} with an {@link CacheStrategy} other than
  * {@link CacheStrategy#none} needs an associated {@link Cache}.
  * <p>
  * The Initialisation of the sub-components:
@@ -137,92 +156,92 @@ import org.slf4j.LoggerFactory;
         metatype = true,
         immediate = true
         )
-@Service(value=ReferencedSite.class)
+@Service(value=Site.class)
 @Properties(value={
         @Property(name=SiteConfiguration.ID),
         @Property(name=SiteConfiguration.NAME),
         @Property(name=SiteConfiguration.DESCRIPTION),
         @Property(name=SiteConfiguration.ENTITY_PREFIX, cardinality=1000),
-        @Property(name=SiteConfiguration.ACCESS_URI),
-        @Property(name=SiteConfiguration.ENTITY_DEREFERENCER_TYPE,
+        @Property(name=ACCESS_URI),
+        @Property(name=ENTITY_DEREFERENCER_TYPE,
             options={
                 @PropertyOption(
-                        value='%'+SiteConfiguration.ENTITY_DEREFERENCER_TYPE+".option.none",
+                        value='%'+ENTITY_DEREFERENCER_TYPE+".option.none",
                         name=""),
                 @PropertyOption(
-                    value='%'+SiteConfiguration.ENTITY_DEREFERENCER_TYPE+".option.sparql",
+                    value='%'+ENTITY_DEREFERENCER_TYPE+".option.sparql",
                     name="org.apache.stanbol.entityhub.dereferencer.SparqlDereferencer"),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.ENTITY_DEREFERENCER_TYPE+".option.coolUri",
+                        value='%'+ReferencedSiteConfiguration.ENTITY_DEREFERENCER_TYPE+".option.coolUri",
                         name="org.apache.stanbol.entityhub.dereferencer.CoolUriDereferencer")
             },value="org.apache.stanbol.entityhub.dereferencer.SparqlDereferencer"),
-        @Property(name=SiteConfiguration.QUERY_URI), //the deri server has better performance
-        @Property(name=SiteConfiguration.ENTITY_SEARCHER_TYPE,
+        @Property(name=QUERY_URI), //the deri server has better performance
+        @Property(name=ENTITY_SEARCHER_TYPE,
             options={
                 @PropertyOption(
-                        value='%'+SiteConfiguration.ENTITY_SEARCHER_TYPE+".option.none",
+                        value='%'+ENTITY_SEARCHER_TYPE+".option.none",
                         name=""),
                 @PropertyOption(
-                    value='%'+SiteConfiguration.ENTITY_SEARCHER_TYPE+".option.sparql",
+                    value='%'+ENTITY_SEARCHER_TYPE+".option.sparql",
                     name="org.apache.stanbol.entityhub.searcher.SparqlSearcher"),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.ENTITY_SEARCHER_TYPE+".option.sparql-virtuoso",
+                        value='%'+ENTITY_SEARCHER_TYPE+".option.sparql-virtuoso",
                         name="org.apache.stanbol.entityhub.searcher.VirtuosoSearcher"),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.ENTITY_SEARCHER_TYPE+".option.sparql-larq",
+                        value='%'+ENTITY_SEARCHER_TYPE+".option.sparql-larq",
                         name="org.apache.stanbol.entityhub.searcher.LarqSearcher")
             },value="org.apache.stanbol.entityhub.searcher.SparqlSearcher"),
-        @Property(name=SiteConfiguration.DEFAULT_SYMBOL_STATE,
+        @Property(name=DEFAULT_SYMBOL_STATE,
             options={
                 @PropertyOption( //seems, that name and value are exchanged ...
-                        value='%'+SiteConfiguration.DEFAULT_SYMBOL_STATE+".option.proposed",
+                        value='%'+DEFAULT_SYMBOL_STATE+".option.proposed",
                         name="proposed"),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.DEFAULT_SYMBOL_STATE+".option.active",
+                        value='%'+DEFAULT_SYMBOL_STATE+".option.active",
                         name="active")
                 //the other states make no sense for new symbols
             }, value="proposed"),
-        @Property(name=SiteConfiguration.DEFAULT_MAPPING_STATE,
+        @Property(name=DEFAULT_MAPPING_STATE,
             options={
                 @PropertyOption(
-                        value='%'+SiteConfiguration.DEFAULT_MAPPING_STATE+".option.proposed",
+                        value='%'+DEFAULT_MAPPING_STATE+".option.proposed",
                         name="proposed"),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.DEFAULT_MAPPING_STATE+".option.confirmed",
+                        value='%'+DEFAULT_MAPPING_STATE+".option.confirmed",
                         name="confirmed")
                 //the other states make no sense for new symbols
             }, value="proposed"),
-        @Property(name=SiteConfiguration.DEFAULT_EXPIRE_DURATION,
+        @Property(name=DEFAULT_EXPIRE_DURATION,
             options={
                 @PropertyOption(
-                        value='%'+SiteConfiguration.DEFAULT_EXPIRE_DURATION+".option.oneMonth",
+                        value='%'+DEFAULT_EXPIRE_DURATION+".option.oneMonth",
                         name=""+(1000L*60*60*24*30)),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.DEFAULT_EXPIRE_DURATION+".option.halfYear",
+                        value='%'+DEFAULT_EXPIRE_DURATION+".option.halfYear",
                         name=""+(1000L*60*60*24*183)),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.DEFAULT_EXPIRE_DURATION+".option.oneYear",
+                        value='%'+DEFAULT_EXPIRE_DURATION+".option.oneYear",
                         name=""+(1000L*60*60*24*365)),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.DEFAULT_EXPIRE_DURATION+".option.none",
+                        value='%'+DEFAULT_EXPIRE_DURATION+".option.none",
                         name="0")
             }, value="0"),
-        @Property(name=SiteConfiguration.CACHE_STRATEGY,
+        @Property(name=CACHE_STRATEGY,
             options={
                 @PropertyOption(
-                        value='%'+SiteConfiguration.CACHE_STRATEGY+".option.none",
+                        value='%'+CACHE_STRATEGY+".option.none",
                         name="none"),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.CACHE_STRATEGY+".option.used",
+                        value='%'+CACHE_STRATEGY+".option.used",
                         name="used"),
                 @PropertyOption(
-                        value='%'+SiteConfiguration.CACHE_STRATEGY+".option.all",
+                        value='%'+CACHE_STRATEGY+".option.all",
                         name="all")
             }, value="none"),
-        @Property(name=SiteConfiguration.CACHE_ID),
-        @Property(name=SiteConfiguration.SITE_FIELD_MAPPINGS,cardinality=1000)
+        @Property(name=CACHE_ID),
+        @Property(name=SITE_FIELD_MAPPINGS,cardinality=1000)
         })
-public class ReferencedSiteImpl implements ReferencedSite {
+public class ReferencedSiteImpl implements Site {
     static final int maxInt = Integer.MAX_VALUE;
     private final Logger log;
     private ComponentContext context;
@@ -243,7 +262,7 @@ public class ReferencedSiteImpl implemen
 
     private ServiceTracker cacheTracker;
     
-    private SiteConfiguration siteConfiguration;
+    private ReferencedSiteConfiguration siteConfiguration;
     /**
      * Stores keys -> values to be added to the metadata of {@link Entity Entities}
      * created by this site.
@@ -281,7 +300,7 @@ public class ReferencedSiteImpl implemen
         return siteConfiguration.getId();
     }
     @Override
-    public QueryResultList<Entity> findEntities(FieldQuery query) throws ReferencedSiteException {
+    public QueryResultList<Entity> findEntities(FieldQuery query) throws SiteException {
         List<Entity> results;
         if(siteConfiguration.getCacheStrategy() == CacheStrategy.all){
             //TODO: check if query can be executed based on the base configuration of the Cache
@@ -294,12 +313,13 @@ public class ReferencedSiteImpl implemen
                     for(Representation result : representations){
                         Entity entity = new EntityImpl(getId(),result,null);
                         results.add(entity);
-                        initEntityMetadata(entity,true);
+                        initEntityMetadata(entity, siteMetadata,
+                            singletonMap(RdfResourceEnum.isChached.getUri(), (Object)Boolean.TRUE));
                     }
                     return new QueryResultListImpl<Entity>(query, results, Entity.class);
                 } catch (YardException e) {
                     if(siteConfiguration.getEntitySearcherType()==null || isOfflineMode()){
-                        throw new ReferencedSiteException("Unable to execute query on Cache "+siteConfiguration.getCacheId(),e);
+                        throw new SiteException("Unable to execute query on Cache "+siteConfiguration.getCacheId(),e);
                     } else {
                         log.warn(String.format("Error while performing query on Cache %s! Try to use remote site %s as fallback!",
                             siteConfiguration.getCacheId(),siteConfiguration.getQueryUri()),e);
@@ -307,7 +327,7 @@ public class ReferencedSiteImpl implemen
                 }
             } else {
                 if(siteConfiguration.getEntitySearcherType()==null || isOfflineMode()){
-                    throw new ReferencedSiteException(String.format("Unable to execute query on Cache %s because it is currently not active",
+                    throw new SiteException(String.format("Unable to execute query on Cache %s because it is currently not active",
                         siteConfiguration.getCacheId()));
                 } else {
                     log.warn(String.format("Cache %s currently not active will query remote Site %s as fallback",
@@ -317,7 +337,7 @@ public class ReferencedSiteImpl implemen
         }
         QueryResultList<String> entityIds;
         if(entitySearcher == null) {
-            throw new ReferencedSiteException(
+            throw new SiteException(
                 String.format("EntitySearcher %s not available for remote site %s!",siteConfiguration.getEntitySearcherType(),
                     siteConfiguration.getQueryUri()));
         }
@@ -325,13 +345,13 @@ public class ReferencedSiteImpl implemen
         try {
             entityIds = entitySearcher.findEntities(query);
         } catch (IOException e) {
-            throw new ReferencedSiteException(String.format("Unable to execute query on remote site %s with entitySearcher %s!",
+            throw new SiteException(String.format("Unable to execute query on remote site %s with entitySearcher %s!",
                     siteConfiguration.getQueryUri(),siteConfiguration.getEntitySearcherType()), e);
         }
         int numResults = entityIds.size();
         List<Entity> entities = new ArrayList<Entity>(numResults);
         int errors = 0;
-        ReferencedSiteException lastError = null;
+        SiteException lastError = null;
         for(String id : entityIds){
             Entity entity;
             try {
@@ -342,7 +362,7 @@ public class ReferencedSiteImpl implemen
                 entities.add(entity);
                 //use the position in the list as resultSocre
                 entity.getRepresentation().set(RdfResourceEnum.resultScore.getUri(), Float.valueOf((float)numResults));
-            } catch (ReferencedSiteException e) {
+            } catch (SiteException e) {
                 lastError = e;
                 errors++;
                 log.warn(String.format("Unable to get Representation for Entity %s. -> %d Error%s for %d Entities in QueryResult (Reason:%s)",
@@ -353,7 +373,7 @@ public class ReferencedSiteImpl implemen
         }
         if(lastError != null){
             if(entities.isEmpty()){
-                throw new ReferencedSiteException("Unable to get anly Representations for Entities selected by the parsed Query (Root-Cause is the last Exception trown)",lastError);
+                throw new SiteException("Unable to get anly Representations for Entities selected by the parsed Query (Root-Cause is the last Exception trown)",lastError);
             } else {
                 log.warn(String.format("Unable to get %d/%d Represetnations for selected Entities.",errors,entityIds.size()));
                 log.warn("Stack trace of the last Exception:",lastError);
@@ -362,7 +382,7 @@ public class ReferencedSiteImpl implemen
         return new QueryResultListImpl<Entity>(query, entities,Entity.class);
     }
     @Override
-    public QueryResultList<Representation> find(FieldQuery query) throws ReferencedSiteException{
+    public QueryResultList<Representation> find(FieldQuery query) throws SiteException{
         if(siteConfiguration.getCacheStrategy() == CacheStrategy.all){
             //TODO: check if query can be executed based on the base configuration of the Cache
             Cache cache = getCache();
@@ -371,7 +391,7 @@ public class ReferencedSiteImpl implemen
                     return cache.find(query);
                 } catch (YardException e) {
                     if(siteConfiguration.getEntitySearcherType()==null || isOfflineMode()){
-                        throw new ReferencedSiteException("Unable to execute query on Cache "+siteConfiguration.getCacheId(),e);
+                        throw new SiteException("Unable to execute query on Cache "+siteConfiguration.getCacheId(),e);
                     } else {
                         log.warn(String.format("Error while performing query on Cache %s! Try to use remote site %s as fallback!",
                             siteConfiguration.getCacheId(),siteConfiguration.getQueryUri()),e);
@@ -379,7 +399,7 @@ public class ReferencedSiteImpl implemen
                 }
             } else {
                 if(siteConfiguration.getEntitySearcherType()==null || isOfflineMode()){
-                    throw new ReferencedSiteException(String.format("Unable to execute query because Cache %s is currently not active",
+                    throw new SiteException(String.format("Unable to execute query because Cache %s is currently not active",
                         siteConfiguration.getCacheId()));
                 } else {
                     log.warn(String.format("Cache %s currently not active will query remote Site %s as fallback",
@@ -388,7 +408,7 @@ public class ReferencedSiteImpl implemen
             }
         }
         if(entitySearcher == null){
-            throw new ReferencedSiteException(
+            throw new SiteException(
                 String.format("EntitySearcher %s not available for remote site %s!",siteConfiguration.getEntitySearcherType(),
                     siteConfiguration.getQueryUri()));
         }
@@ -396,12 +416,12 @@ public class ReferencedSiteImpl implemen
         try {
             return entitySearcher.find(query);
         } catch (IOException e) {
-            throw new ReferencedSiteException("Unable execute Query on remote site "+
+            throw new SiteException("Unable execute Query on remote site "+
                 siteConfiguration.getQueryUri(),e);
         }
     }
     @Override
-    public QueryResultList<String> findReferences(FieldQuery query) throws ReferencedSiteException {
+    public QueryResultList<String> findReferences(FieldQuery query) throws SiteException {
         if(siteConfiguration.getCacheStrategy() == CacheStrategy.all){
             //TODO: check if query can be executed based on the base configuration of the Cache
             Cache cache = getCache();
@@ -410,7 +430,7 @@ public class ReferencedSiteImpl implemen
                     return cache.findReferences(query);
                 } catch (YardException e) {
                     if(siteConfiguration.getEntitySearcherType()==null || isOfflineMode()){
-                        throw new ReferencedSiteException("Unable to execute query on Cache "+siteConfiguration.getCacheId(),e);
+                        throw new SiteException("Unable to execute query on Cache "+siteConfiguration.getCacheId(),e);
                     } else {
                         log.warn(String.format("Error while performing query on Cache %s! Try to use remote site %s as fallback!",
                             siteConfiguration.getCacheId(),siteConfiguration.getQueryUri()),e);
@@ -418,7 +438,7 @@ public class ReferencedSiteImpl implemen
                 }
             } else {
                 if(siteConfiguration.getEntitySearcherType()==null  || isOfflineMode()){
-                    throw new ReferencedSiteException(
+                    throw new SiteException(
                         String.format("Unable to execute query on Cache %s because it is currently not active",
                             siteConfiguration.getCacheId()));
                 } else {
@@ -428,7 +448,7 @@ public class ReferencedSiteImpl implemen
             }
         }
         if(entitySearcher == null){
-            throw new ReferencedSiteException(
+            throw new SiteException(
                 String.format("EntitySearcher %s not available for remote site %s!",siteConfiguration.getEntitySearcherType(),
                     siteConfiguration.getQueryUri()));
         }
@@ -436,19 +456,19 @@ public class ReferencedSiteImpl implemen
         try {
             return entitySearcher.findEntities(query);
         } catch (IOException e) {
-            throw new ReferencedSiteException("Unable execute Query on remote site "+
+            throw new SiteException("Unable execute Query on remote site "+
                 siteConfiguration.getQueryUri(),e);
         }
     }
     @Override
-    public InputStream getContent(String id, String contentType) throws ReferencedSiteException {
+    public InputStream getContent(String id, String contentType) throws SiteException {
         if(siteConfiguration.getEntityDereferencerType() == null){
-            throw new ReferencedSiteException(
+            throw new SiteException(
                 String.format("Unable to get Content for Entity %s because No dereferencer configured for ReferencedSite %s",
                     id,getId()));
         }
         if(dereferencer == null){
-            throw new ReferencedSiteException(
+            throw new SiteException(
                 String.format("Dereferencer %s for remote site %s is not available",siteConfiguration.getEntityDereferencerType(),
                 siteConfiguration.getAccessUri()));
         }
@@ -456,13 +476,13 @@ public class ReferencedSiteImpl implemen
         try {
             return dereferencer.dereference(id, contentType);
         } catch (IOException e) {
-            throw new ReferencedSiteException(
+            throw new SiteException(
                 String.format("Unable to load content for Entity %s and mediaType %s from remote site %s by using dereferencer %s",
                     id,contentType,siteConfiguration.getAccessUri(),siteConfiguration.getEntityDereferencerType()),e);
         }
     }
     @Override
-    public Entity getEntity(String id) throws ReferencedSiteException {
+    public Entity getEntity(String id) throws SiteException {
         Cache cache = getCache();
         Entity entity = null;
         long start = System.currentTimeMillis();
@@ -471,13 +491,14 @@ public class ReferencedSiteImpl implemen
                 Representation rep = cache.getRepresentation(id);
                 if(rep != null){
                    entity = new EntityImpl(getId(), rep, null);
-                   initEntityMetadata(entity, true);
+                   initEntityMetadata(entity, siteMetadata,
+                       singletonMap(RdfResourceEnum.isChached.getUri(), (Object)Boolean.TRUE));
                 } else if(siteConfiguration.getCacheStrategy() == CacheStrategy.all){
                     return null; //do no remote lokkups on CacheStrategy.all!!
                 }
             } catch (YardException e) {
                 if (siteConfiguration.getEntityDereferencerType() == null || isOfflineMode()) {
-                    throw new ReferencedSiteException(String.format("Unable to get Represetnation %s form Cache %s",
+                    throw new SiteException(String.format("Unable to get Represetnation %s form Cache %s",
                         id, siteConfiguration.getCacheId()), e);
                 } else {
                     log.warn(String.format("Unable to get Represetnation %s form Cache %s. Will dereference from remote site %s",
@@ -486,7 +507,7 @@ public class ReferencedSiteImpl implemen
             }
         } else {
             if (siteConfiguration.getEntityDereferencerType() == null || isOfflineMode()) {
-                throw new ReferencedSiteException(String.format("Unable to get Represetnation %s because configured Cache %s is currently not available",
+                throw new SiteException(String.format("Unable to get Represetnation %s because configured Cache %s is currently not available",
                         id, siteConfiguration.getCacheId()));
             } else {
                 log.warn(String.format("Cache %s is currently not available. Will use remote site %s to load Representation %s",
@@ -495,7 +516,7 @@ public class ReferencedSiteImpl implemen
         }
         if (entity == null) { // no cache or not found in cache
             if(dereferencer == null){
-                throw new ReferencedSiteException(String.format("Entity Dereferencer %s for accessing remote site %s is not available",
+                throw new SiteException(String.format("Entity Dereferencer %s for accessing remote site %s is not available",
                     siteConfiguration.getEntityDereferencerType(),siteConfiguration.getAccessUri()));
             }
             ensureOnline(siteConfiguration.getAccessUri(), dereferencer.getClass());
@@ -503,7 +524,7 @@ public class ReferencedSiteImpl implemen
             try {
                 rep = dereferencer.dereference(id);
             } catch (IOException e) {
-                throw new ReferencedSiteException(
+                throw new SiteException(
                     String.format("Unable to load Representation for entity %s form remote site %s with dereferencer %s",
                         id, siteConfiguration.getAccessUri(), siteConfiguration.getEntityDereferencerType()), e);
             }
@@ -523,7 +544,8 @@ public class ReferencedSiteImpl implemen
                     }
                 }
                 entity = new EntityImpl(getId(), rep, null);
-                initEntityMetadata(entity, cachedVersion);
+                initEntityMetadata(entity, siteMetadata,
+                	singletonMap(RdfResourceEnum.isChached.getUri(), (Object)cachedVersion));
             }
         } else {
             log.debug("  - loaded Representation {} from Cache in {} ms",
@@ -531,22 +553,7 @@ public class ReferencedSiteImpl implemen
         }
         return entity;
     }
-    /**
-     * Initialises the {@link Entity#getMetadata()} with the properties
-     * configured for this site (attribution and license information)
-     * @param entity the entity
-     * @param of this Entity is locally cached or not. If <code>null</code>
-     * this information is not set in the metadata.
-     */
-    private void initEntityMetadata(Entity entity, Boolean isChached) {
-        Representation metadata = entity.getMetadata();
-        if(isChached != null){
-            metadata.set(RdfResourceEnum.isChached.getUri(), isChached);
-        }
-        for(Entry<String,Object> entry : siteMetadata.entrySet()){
-            metadata.add(entry.getKey(), entry.getValue());
-        }
-    }
+
     @Override
     public SiteConfiguration getConfiguration() {
         return siteConfiguration;
@@ -562,8 +569,8 @@ public class ReferencedSiteImpl implemen
     }
     @Override
     public boolean equals(Object obj) {
-        if(obj instanceof ReferencedSite) {
-            SiteConfiguration osc = ((ReferencedSite)obj).getConfiguration();
+        if(obj instanceof Site) {
+            SiteConfiguration osc = ((Site)obj).getConfiguration();
             //this will return false if one of the two sites is not activated
             // -> this should be OK
             return siteConfiguration != null && osc != null &&
@@ -640,15 +647,8 @@ public class ReferencedSiteImpl implemen
         }
         this.context = context;
         //create the SiteConfiguration based on the parsed properties
-        Map<String,Object> config = new HashMap<String,Object>();
-        Dictionary<String,Object> properties = (Dictionary<String,Object>)context.getProperties();
-        //copy the properties to a map
-        for(Enumeration<String> e = properties.keys();e.hasMoreElements();){
-            String key = e.nextElement();
-            config.put(key, properties.get(key));
-        }
         //NOTE that the constructor also validation of the parsed configuration
-        siteConfiguration = new DefaultSiteConfiguration(config);
+        siteConfiguration = new ReferencedSiteConfigurationImpl(context.getProperties());
         if(PROHIBITED_SITE_IDS.contains(siteConfiguration.getId().toLowerCase())){
             throw new ConfigurationException(SiteConfiguration.ID, String.format(
                 "The ID '%s' of this Referenced Site is one of the following " +
@@ -656,34 +656,7 @@ public class ReferencedSiteImpl implemen
                 PROHIBITED_SITE_IDS));
         }
         log.info(" > initialise Referenced Site {}",siteConfiguration.getName());
-        siteMetadata = new HashMap<String,Object>();
-        ValueFactory vf = InMemoryValueFactory.getInstance();
-        if(siteConfiguration.getAttribution() != null){
-            siteMetadata.put(NamespaceEnum.cc.getNamespace()+"attributionName", 
-                vf.createText(siteConfiguration.getAttribution()));
-        }
-        if(siteConfiguration.getAttributionUrl() != null){
-            siteMetadata.put(NamespaceEnum.cc.getNamespace()+"attributionURL", 
-                vf.createReference(siteConfiguration.getAttributionUrl()));
-        }
-        //add the licenses
-        if(siteConfiguration.getLicenses() != null){
-            for(License license : siteConfiguration.getLicenses()){
-                if(license.getUrl() != null){
-                    siteMetadata.put(NamespaceEnum.cc.getNamespace()+"license", 
-                        vf.createReference(license.getUrl()));
-                } else if(license.getText() != null){
-                    siteMetadata.put(NamespaceEnum.cc.getNamespace()+"license", 
-                        vf.createText(license.getText()));
-                }
-                //if defined add the name to dc:license
-                if(license.getName() != null){
-                    siteMetadata.put(NamespaceEnum.dcTerms.getNamespace()+"license", 
-                        vf.createText(license.getName()));
-                }
-                //link to the license via cc:license
-            }
-        }
+        this.siteMetadata = extractSiteMetadata(siteConfiguration);
         
         //if the accessUri is the same as the queryUri and both the dereferencer and
         //the entitySearcher uses the same component, than we need only one component
@@ -723,6 +696,7 @@ public class ReferencedSiteImpl implemen
         }
     }
 
+
     /**
      * Initialise the dereferencer and searcher component as soon as the according
      * {@link ComponentFactory} gets registered.<p>
@@ -774,7 +748,7 @@ public class ReferencedSiteImpl implemen
         }
     }
     /**
-     * Creates the entity searcher component used by this {@link ReferencedSite}
+     * Creates the entity searcher component used by this {@link Site}
      * (and configured via the {@link SiteConfiguration#ENTITY_SEARCHER_TYPE} property).<p>
      * If the {@link SiteConfiguration#ENTITY_DEREFERENCER_TYPE} is set to the same vale
      * and the {@link #accessUri} also equals the {@link #queryUri}, than the
@@ -797,7 +771,7 @@ public class ReferencedSiteImpl implemen
         }
     }
     /**
-     * Creates the entity dereferencer component used by this {@link ReferencedSite}.
+     * Creates the entity dereferencer component used by this {@link Site}.
      * The implementation used as the dereferencer is configured by the
      * {@link SiteConfiguration#ENTITY_DEREFERENCER_TYPE} property.
      * @param factory the component factory used to create the {@link #dereferencer}
@@ -913,17 +887,17 @@ public class ReferencedSiteImpl implemen
         return offlineMode != null;
     }
     /**
-     * Basically this Method throws an {@link ReferencedSiteException} in case
+     * Basically this Method throws an {@link SiteException} in case
      * Stanbol operates in offline mode
      * @param uri the URI of the remote service
      * @param clazz the clazz of the service that would like to refer the remote
      * service
-     * @throws ReferencedSiteException in case {@link #isOfflineMode()} returns
+     * @throws SiteException in case {@link #isOfflineMode()} returns
      * <code>true</code>
      */
-    private void ensureOnline(String uri, Class<?> clazz) throws ReferencedSiteException {
+    private void ensureOnline(String uri, Class<?> clazz) throws SiteException {
         if(isOfflineMode()){
-            throw new ReferencedSiteException(String.format(
+            throw new SiteException(String.format(
                 "Unable to access remote Service %s by using %s because Stanbol runs in OfflineMode",
                 uri,clazz.getSimpleName()));
         }
--- incubator/stanbol/trunk/enhancer/engines/entitytagging/src/main/java/org/apache/stanbol/enhancer/engines/entitytagging/impl/NamedEntityTaggingEngine.java (original)
+++ incubator/stanbol/trunk/enhancer/engines/entitytagging/src/main/java/org/apache/stanbol/enhancer/engines/entitytagging/impl/NamedEntityTaggingEngine.java Tue Jul 10 09:29:59 2012
@@ -69,9 +69,9 @@ import org.apache.stanbol.entityhub.serv
 import org.apache.stanbol.entityhub.servicesapi.query.QueryResultList;
 import org.apache.stanbol.entityhub.servicesapi.query.ReferenceConstraint;
 import org.apache.stanbol.entityhub.servicesapi.query.TextConstraint;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSite;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteException;
-import org.apache.stanbol.entityhub.servicesapi.site.ReferencedSiteManager;
+import org.apache.stanbol.entityhub.servicesapi.site.Site;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteException;
+import org.apache.stanbol.entityhub.servicesapi.site.SiteManager;
 import org.osgi.framework.Constants;
 import org.osgi.service.cm.ConfigurationException;
 import org.osgi.service.component.ComponentContext;
@@ -79,7 +79,7 @@ import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
 /**
- * Engine that uses a {@link ReferencedSite} to search for entities for existing TextAnnotations of an Content
+ * Engine that uses a {@link Site} to search for entities for existing TextAnnotations of an Content
  * Item.
  * 
  * @author ogrisel, rwesten
@@ -141,7 +141,7 @@ public class NamedEntityTaggingEngine 
      * configured Referenced Site when we need to enhance a content item.
      */
     @Reference
-    protected ReferencedSiteManager siteManager;
+    protected SiteManager siteManager;
 
     /**
      * Used to lookup Entities if the {@link #REFERENCED_SITE_ID} property is
@@ -151,7 +151,7 @@ public class NamedEntityTaggingEngine 
     protected Entityhub entityhub;
     
     /**
-     * This holds the id of the {@link ReferencedSite} used to lookup Entities
+     * This holds the id of the {@link Site} used to lookup Entities
      * or <code>null</code> if the {@link Entityhub} is used. 
      */
     protected String referencedSiteID;
@@ -212,7 +212,7 @@ public class NamedEntityTaggingEngine 
 
     /**
      * The {@link OfflineMode} is used by Stanbol to indicate that no external service should be referenced.
-     * For this engine that means it is necessary to check if the used {@link ReferencedSite} can operate
+     * For this engine that means it is necessary to check if the used {@link Site} can operate
      * offline or not.
      * 
      * @see #enableOfflineMode(OfflineMode)
@@ -302,9 +302,9 @@ public class NamedEntityTaggingEngine 
     }
 
     public void computeEnhancements(ContentItem ci) throws EngineException {
-        final ReferencedSite site;
+        final Site site;
         if(referencedSiteID != null) { //lookup the referenced site
-            site = siteManager.getReferencedSite(referencedSiteID);
+            site = siteManager.getSite(referencedSiteID);
             //ensure that it is present
             if (site == null) {
                 String msg = String.format(
@@ -401,7 +401,7 @@ public class NamedEntityTaggingEngine 
 
     /**
      * Computes the Enhancements
      * @param site The {@link ReferencedSiteException} id or <code>null</code> to
      * use the {@link Entityhub}
      * @param literalFactory the {@link LiteralFactory} used to create RDF Literals
      * @param contentItemId the id of the contentItem
@@ -413,7 +413,7 @@ public class NamedEntityTaggingEngine 
      * @throws EntityhubException On any Error while looking up Entities via
      * the Entityhub
      */
-    protected final List<Suggestion> computeEntityRecommentations(ReferencedSite site,
+    protected final List<Suggestion> computeEntityRecommentations(Site site,
             NamedEntity namedEntity,
             List<UriRef> subsumedAnnotations, String language) throws EntityhubException {
         // First get the required properties for the parsed textAnnotation
@@ -401,7 +401,7 @@ public class NamedEntityTaggingEngine 
     /**
      * Computes the Enhancements
-     * @param site The {@link ReferencedSiteException} id or <code>null</code> to
+     * @param site The {@link SiteException} id or <code>null</code> to
      * use the {@link Entityhub}
      * @param literalFactory the {@link LiteralFactory} used to create RDF Literals

Modified: incubator/stanbol/trunk/enhancer/engines/keywordextraction/pom.xml
URL: http://svn.apache.org/viewvc/incubator/stanbol/trunk/enhancer/engines/keywordextraction/pom.xml?rev=1359535&r1=1359534&r2=1359535&view=diff
==============================================================================